@@ -6,21 +6,25 @@ from ..models import (
     CryptodotcomResponseMessage,
     EnhancedWebsocket,
     CryptodotcomRequestMessage,
-    EnhancedWebsocketBehaviorSubject
+    EnhancedWebsocketBehaviorSubject,
 )
-from ..connection.request_response import wait_for_response
-from ..events import MethodName
+
+
 from ..rest import get_user_open_orders_factory
-from returns.curry import curry
-from expression import curry_flip
+
+from ..operators.stream.response_messages import extract_data
+from ..models import OrderDict
 
 from .subscribe import subscribe_to_channel
 from ccxt import cryptocom
 
 OpenOrdersData = list[Order]
 
+
 def _subscribe_open_orders(
-    messages: Observable[CryptodotcomResponseMessage], instrument: str = "", unsubscribe_on_dispose: bool = True
+    messages: Observable[CryptodotcomResponseMessage],
+    instrument: str = "",
+    unsubscribe_on_dispose: bool = True,
 ):
     instrument = instrument.replace("/", "_")
     channel = "user.order" + ("" if not instrument else f".{instrument}")
@@ -30,6 +34,7 @@ def _subscribe_open_orders(
 def to_open_orders_entries(exchange: cryptocom):
     def to_open_orders_entries_(message: CryptodotcomResponseMessage):
         return cast(list[dict], exchange.parse_orders(message))
+
     return to_open_orders_entries_
 
 
@@ -39,7 +44,7 @@ def subscribe_open_orders_reload(
     socket: EnhancedWebsocketBehaviorSubject,
     exchange: cryptocom,
     symbol: str = "",
-    unsubscribe_on_dispose: bool = True
+    unsubscribe_on_dispose: bool = True,
 ) -> Callable[[Observable[EnhancedWebsocket]], Observable[list[dict]]]:
     """Subscribe to open orders, but each time it emits (it emits updates only), we reload the actual open orders snapshot via RE
 
@@ -56,7 +61,7 @@ def subscribe_open_orders_reload(
     """
     instrument = ""
     if symbol:
-        instrument = exchange.market(symbol)['id']
+        instrument = exchange.market(symbol)["id"]
 
     get_open_orders = get_user_open_orders_factory(response_messages, socket, exchange)
 
@@ -71,16 +76,15 @@ def subscribe_open_orders_reload(
 
 
 def subscribe_open_orders(
-    all_messages: Observable[CryptodotcomResponseMessage], exchange: cryptocom, instrument: str = "", unsubscribe_on_dispose: bool = True
-):
+    all_messages: Observable[CryptodotcomResponseMessage],
+    instrument: str = "",
+    unsubscribe_on_dispose: bool = True,
+) -> Callable[[Observable[EnhancedWebsocket]], Observable[list[OrderDict]]]:
     """Unparsed orders (only extracted result array)"""
     return compose(
         _subscribe_open_orders(all_messages, instrument, unsubscribe_on_dispose),
-        operators.map(lambda message: message.result["data"]),
+        extract_data(),  # type: ignore
     )
 
 
-__all__ = [
-    "subscribe_open_orders",
-    "subscribe_open_orders_reload"
-]
+__all__ = ["subscribe_open_orders", "subscribe_open_orders_reload"]
