@@ -4,8 +4,16 @@ from .request import CryptodotcomRequestMessage
 from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubject
 from .user_balance import UserBalance, PositionBalance
 from .trade import Trade
-from .book import RawOrderbook, RawOrderbookEntry, OrderbookEntryNamedTuple, OrderbookDict
+from .book import (
+    RawOrderbook,
+    RawOrderbookEntry,
+    OrderbookEntryNamedTuple,
+    OrderbookDict,
+)
 from .framework import BookConfig, CryptodotcomContext
+from .status import Status
+from .message_types import MessageTypes
+from .bundle import WebsocketBundle, WebsocketMessageBundle, WebsocketStatusBundle
 
 __all__ = [
     "BookConfig",
@@ -14,6 +22,7 @@ __all__ = [
     "CryptodotcomResponseMessage",
     "EnhancedWebsocket",
     "EnhancedWebsocketBehaviorSubject",
+    "MessageTypes",
     "Order",
     "OrderbookDict",
     "OrderbookEntryNamedTuple",
@@ -24,6 +33,10 @@ __all__ = [
     "PositionBalance",
     "RawOrderbook",
     "RawOrderbookEntry",
+    "Status",
     "Trade",
     "UserBalance",
+    "WebsocketBundle",
+    "WebsocketMessageBundle",
+    "WebsocketStatusBundle",
 ]
