@@ -1,19 +1,26 @@
 from .user_balance import get_user_balance_factory, user_balance_for_instrument
 from .create_order import create_order_factory
-from .cancel_all import cancel_all_factory
+from .cancel_all import cancel_all_factory, cancel_all_http_factory
+from .cancel_order import cancel_order_factory
 from .user_open_orders import get_user_open_orders_factory
 from .get_positions import get_positions_factory
 from .get_deposit_address import get_deposit_address_factory
-from .close_position import close_position_factory
+from .close_position import close_position_factory, close_position_http_factory
+from .user_get_trades import get_user_trades_http, get_user_trades_factory
 
 
 __all__ = [
-    "get_user_balance_factory",
-    "create_order_factory",
     "cancel_all_factory",
-    "get_positions_factory",
-    "user_balance_for_instrument",
-    "get_deposit_address_factory",
-    "get_user_open_orders_factory",
+    "cancel_all_http_factory",
+    "cancel_order_factory",
     "close_position_factory",
-]
\ No newline at end of file
+    "close_position_http_factory",
+    "create_order_factory",
+    "get_deposit_address_factory",
+    "get_positions_factory",
+    "get_user_balance_factory",
+    "get_user_open_orders_factory",
+    "get_user_trades_http",
+    "get_user_trades_factory",
+    "user_balance_for_instrument",
+]
